@@ -408,8 +408,15 @@ class TicketFolder(object):
 
     @classmethod
     def clone(cls, ticket_url, jira, path=None):
+        match = re.match('.*\/browse\/(\w+-\d+)\/?', ticket_url)
+        if not match:
+            raise exceptions.JirafsError(
+                    "\'%s\' is not a valid JIRA ticket URL." % (
+                        ticket_url
+                    )
+            )
         if not path:
-            path = re.match('.*\/browse\/(\w+-\d+)\/?', ticket_url).group(1)
+            path = match.group(1)
         path = os.path.realpath(path)
         os.mkdir(path)
         folder = cls.initialize_ticket_folder(ticket_url, path, jira)
@@ -910,10 +917,11 @@ class TicketFolder(object):
             if self.version < constants.CURRENT_REPO_VERSION:
                 print(
                     "Your ticket folder is out-of-date and must be updated.  "
-                    "Migrations are not necessarily lossless; please record "
-                    "your current changes before proceeding with migrations."
+                    "Although migrations will never affect the JIRA issue "
+                    "itself, they may modify your local clone of the issue; "
+                    "please record your current changes before proceeding."
                 )
-                result = utils.convert_to_boolean(input("Proceed? (N/y)"))
+                result = utils.convert_to_boolean(input("Continue? (N/Y): "))
                 if not result:
                     sys.exit(1)
         while self.version < constants.CURRENT_REPO_VERSION:
